``eradiate.contexts``
=====================

Classes
-------

.. automodule:: eradiate.contexts

.. py:currentmodule:: eradiate.contexts

.. autosummary::
   :toctree: generated/autosummary/

   Context
   KernelContext
